# 
# Utility functions for the Demand Prediction Challenge (dpc)
# 
# Some helper functions for parsing/processing data
# 

from pylab import *
import datetime as dt
import json as js
import pandas as pd

def parseUTCStrings (rawData):
    """
    Parse an array of UTC-formatted strings.

    This function strips the Time Zone information of the UTC-formatted
    strings in the input array, then turns them into datetime.datetime objects.

    Parameters
    ----------
    rawData : array_like
        strings in UTC format

    Returns
    -------
    out : datetime.datetime array
        array of datetime.datetime values
    """
    return map(lambda x: dt.datetime.strptime(x.split('+')[0],'%Y-%m-%dT%H:%M:%S'), rawData)

def getTimeSeries (timeStamps):
    """
    Get a PANDAS TimeSeries indexed by the input array.

    This function produces a PANDAS Series of all 1's, but indexed
    by the input array of datetime.datetime objects.  That turns it
    into a TimeSeries object.
    
    Parameters
    ----------
    timeStamps : array of datetime.datetime

    Returns
    -------
    out : pd.TimeSeries
    """
    return pd.Series(1, index=pd.DatetimeIndex(timeStamps))

def binUp (x):
    """
    Bin TimeSeries values by hour

    This function essentially computes a histogram, binning TimeSeries
    values by hour and also drops Null values.

    Parameters
    ----------
    x : pd.TimeSeries
        Input data

    Returns
    -------
    out : pd.TimeSeries
        Binned
    """
    return x.resample('1H', how='sum').dropna()

